@@ -13,14 +13,20 @@
 #' * Pvalue p-value associated with testing the null hypothesis.
 #' * WP calculated win probability.
 #' * WP_SE standard error of the win probability.
+#' * WP_SD standard deviation of the win probability, calculated as `WP_SE` multiplied by `sqrt(N)`.
+#' * N total number of patients in the analysis.
+#' * formula returning the specified formula in the `x` argument.
+#' * ref showing how the reference group was selected. Can be modifying by specifying the `ref` argument.
 #' @export
+#' @md
+#' @seealso [hce::calcWO()], [hce::calcWO.hce()], [hce::calcWO.data.frame()].
 #' @examples
 #' #Example 1
 #' data(HCE1)
 #' calcWO(AVAL ~ TRTP, data = HCE1)
 #'
 #'#Example 2
-#' calcWO(data = iris[iris$Species != "setosa",], Sepal.Width ~ Species)
+#' calcWO(data = COVID19, GROUP ~ TRTP)
 #'
 calcWO.formula <- function(x, data, ...){
   Args <- base::list(...)
@@ -40,7 +46,13 @@ calcWO.formula <- function(x, data, ...){
   if(! ref %in% Level) stop(base::paste("Choose the reference from the values",
                                   base::paste(Level, collapse = ", ")))
 
-  res <- calcWO.data.frame(x = mf, AVAL = formulavars[1], TRTP = formulavars[2], ref = ref)
+  if(!base::is.null(Args[["alpha"]])) alpha <- Args[["alpha"]]
+  else alpha <- 0.05
+  if(!base::is.null(Args[["WOnull"]])) WOnull <- Args[["WOnull"]]
+  else WOnull <- 1
+  
+  res <- calcWO.data.frame(x = mf, AVAL = formulavars[1], TRTP = formulavars[2], 
+                           ref = ref, alpha = alpha, WOnull = WOnull)
   res$formula <- base::deparse(formula0)
   res$ref <- base::paste(Level[Level != ref],"vs", ref)
   res
